<meta charset="utf-8">
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="viewport" content="width=device-width, initial-scale=1">
<link href="{{ url_for('feed',name='recent') }}"
      rel="alternate"
      title="Recent posts"
      type="application/atom+xml">
{% if page != None %}
     {% if page.descripton!= None %}
        <meta name="description" content="{{ page.description }}" >
     {% else %}
         {% if page.summary!=None %}
            <meta name="description" content="{{ page.summary }}" >
         {% endif %}
     {% endif %}
     {% if page.tags !=None %}
         <meta name="keywords" content="{{ page.tags }}">
     {% endif %}
{% endif %}