{% import "bootstrap/google.html" as ga %}
<!DOCTYPE html>
<html {% block html_attrs %}{% endblock html_attrs %}>
<head lang="en">
    <title>{% block title %}{{ site.title }}{% if page %} - {{ page.title }}{% endif %}{% endblock %}</title>
    {% include "_includes/_metas.html" %}
    {% include "includes/metas.html" ignore missing %}
    {% block styles %}
        <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/font-awesome/4.3.0/css/font-awesome.min.css">
        <link href="{{ bootstrap_find_resource('css/bootstrap.css', cdn='bootstrap') }}" rel="stylesheet"
              media="screen">
        <link rel="stylesheet" href="//cdnjs.cloudflare.com/ajax/libs/highlight.js/8.4/styles/monokai_sublime.min.css">
        {% assets "css" %}
            <link rel="stylesheet" href="{{ ASSET_URL }}">
        {% endassets %}
    {% endblock %}
    <!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
    <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
    <!--[if lt IE 9]>
      <script src="https://oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js"></script>
      <script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
    <![endif]-->
    {% block scripts %}
        <script src="{{ bootstrap_find_resource('jquery.js', cdn='jquery') }}"></script>
        <script src="{{ bootstrap_find_resource('js/bootstrap.js', cdn='bootstrap') }}"></script>
        <script src="//cdnjs.cloudflare.com/ajax/libs/highlight.js/8.4/highlight.min.js"></script>
        <script src="//cdnjs.cloudflare.com/ajax/libs/waypoints/2.0.5/waypoints.min.js"></script>
        <script>hljs.initHighlightingOnLoad();</script>
    {% endblock %}
    {% assets "js" %}
        <script type="text/javascript" src="{{ ASSET_URL }}"></script>
    {% endassets %}
</head>
<body {% block body_attrs %}{% endblock body_attrs %}>
{% block body %}
<div class="container">
    <div class="page-wrapper">
        {% block header %}
            {% include ["includes/header.html" , "_includes/_header.html"] ignore missing %}
        {% endblock %}
        {% block navbar %}
            {% include ["includes/navbar.html" , "_includes/_navbar.html"] ignore missing %}
        {% endblock %}
        <div class="page-content">
            {% block content %}
            {% if page.cover %}
                <div class="page-cover">
                    <img src="{{ page.cover }}"/></div>
            {% endif %}
            {% autoescape false %}{{ page.html }}{% endautoescape %}
            {% endblock %}
        </div>
    </div>
</div>
{% block footer %}
    {% include ["includes/footer.html" , "_includes/_footer.html"] ignore missing %}
{% endblock %}
{% endblock %}
{% if site.ga_account %}
    {{ ga.analytics(site.ga_account) }}
{% endif %}
</body>
</html>

